===========================
Unitary Event Analysis (UE)
===========================

.. automodule:: elephant.unitary_event_analysis

Author Contributions
--------------------

- Vahid Rostami (VR)
- Sonja Gruen (SG)
- Markus Diesmann (MD)

VR implemented the method, SG and MD provided guidance.


References
----------

.. bibliography:: ../bib/elephant.bib
   :labelprefix: ue
   :keyprefix: unitary_event_analysis-
   :style: unsrt
